==> kubernetes-model-flowcontrol-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta1/FlowSchemaBuilder.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class FlowSchemaBuilder extends io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchemaFluentImpl<io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchemaBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchema,io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchemaBuilder>{
  public FlowSchemaBuilder() {
    this(false);
  }
  public FlowSchemaBuilder(java.lang.Boolean validationEnabled) {
    this(new FlowSchema(), validationEnabled);
  }
  public FlowSchemaBuilder(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchemaFluent<?> fluent) {
    this(fluent, false);
  }
  public FlowSchemaBuilder(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchemaFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new FlowSchema(), validationEnabled);
  }
  public FlowSchemaBuilder(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchemaFluent<?> fluent,io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchema instance) {
    this(fluent, instance, false);
  }
  public FlowSchemaBuilder(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchemaFluent<?> fluent,io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchema instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public FlowSchemaBuilder(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchema instance) {
    this(instance,false);
  }
  public FlowSchemaBuilder(io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchema instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchemaFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.flowcontrol.v1beta1.FlowSchema build() {
    FlowSchema buildable = new FlowSchema(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FlowSchemaBuilder that = (FlowSchemaBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-flowcontrol-6.1.1-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta1/FlowSchemaBuilder.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class FlowSchemaBuilder extends FlowSchemaFluentImpl<FlowSchemaBuilder> implements VisitableBuilder<FlowSchema,FlowSchemaBuilder>{
  public FlowSchemaBuilder() {
    this(false);
  }
  public FlowSchemaBuilder(Boolean validationEnabled) {
    this(new FlowSchema(), validationEnabled);
  }
  public FlowSchemaBuilder(FlowSchemaFluent<?> fluent) {
    this(fluent, false);
  }
  public FlowSchemaBuilder(FlowSchemaFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new FlowSchema(), validationEnabled);
  }
  public FlowSchemaBuilder(FlowSchemaFluent<?> fluent,FlowSchema instance) {
    this(fluent, instance, false);
  }
  public FlowSchemaBuilder(FlowSchemaFluent<?> fluent,FlowSchema instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public FlowSchemaBuilder(FlowSchema instance) {
    this(instance,false);
  }
  public FlowSchemaBuilder(FlowSchema instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  FlowSchemaFluent<?> fluent;
  Boolean validationEnabled;
  public FlowSchema build() {
    FlowSchema buildable = new FlowSchema(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
